@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw( Alien::Base );
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
 
 1;
@@ -21,8 +21,6 @@ Alien::spatialite - Alien package for the spatialite library
  
 <p>
     <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
-    <a href="https://travis-ci.org/shawnlaffan/perl-alien-spatialite"><img src="https://travis-ci.org/shawnlaffan/perl-alien-spatialite.svg?branch=master" /></a>
-    <a href="https://ci.appveyor.com/project/shawnlaffan/perl-alien-spatialite"><img src="https://ci.appveyor.com/api/projects/status/3lv9qu9ea2ex3p5d?svg=true" /></a>
 </p>
 
 =end HTML
